# eric7.MicroPython.MicroPythonFileSystemUtilities

Module implementing some file system utility functions.

### Global Attributes

None

### Classes

None

### Functions

decoratedName | Function to decorate the given name according to the given mode.
fstat | Function to get the stat() of file.
isVisible | Function to check, if a filesystem entry is a hidden file or directory.
listdirStat | Function to get a list of directory entries and associated stat() tuples.
mode2string | Function to convert a mode value to a string representation.
mtime2string | Function to convert a time value to a string representation.

## decoratedName

decoratedName(name, mode, isDir=False)

Function to decorate the given name according to the given mode.

name (str)
  file or directory name
mode (int)
  mode value
isDir (bool)
  flag indicating that name is a directory

Return:
  decorated file or directory name

Return Type:
  str

Up

## fstat

fstat(filename)

Function to get the stat() of file.

filename (str)
  name of the file

Return:
  tuple containing the stat() result

Return Type:
  tuple

Up

## isVisible

isVisible(name, showHidden)

Function to check, if a filesystem entry is a hidden file or directory.

name (str)
  name to be checked
showHidden (bool)
  flag indicating to show hidden files as well

Return:
  flag indicating a visible filesystem entry

Return Type:
  bool

Up

## listdirStat

listdirStat(dirname, showHidden=False)

Function to get a list of directory entries and associated stat() tuples.

dirname (str)
  name of the directory to list
showHidden (bool)
  flag indicating to show hidden files as well

Return:
  list of tuples containing the entry name and the associated stat() tuple

Return Type:
  list of tuple of (str, tuple)

Up

## mode2string

mode2string(mode)

Function to convert a mode value to a string representation.

mode (int)
  mode value

Return:
  string representation of the given mode value

Return Type:
  str

Up

## mtime2string

mtime2string(mtime)

Function to convert a time value to a string representation.

mtime (int)
  time value

Return:
  string representation of the given time

Return Type:
  str

Up